package com.hgsoft.selfclse.timing.business.utils;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.RandomAccessFile;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.Enumeration;
import java.util.stream.Stream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class FileUtil {

   private static Logger logger = LoggerFactory.getLogger(FileUtil.class);
   private static final int BUFFER_SIZE = 2048;


   public static boolean createFile(File fileName) throws Exception {
      boolean flag = false;

      try {
         if(!fileName.exists()) {
            fileName.createNewFile();
            flag = true;
         }
      } catch (Exception var3) {
         var3.printStackTrace();
      }

      return true;
   }

   public static String readTxtFile(File fileName) throws Exception {
      String result = null;
      FileReader fileReader = null;
      BufferedReader bufferedReader = null;

      try {
         fileReader = new FileReader(fileName);
         bufferedReader = new BufferedReader(fileReader);

         try {
            for(String e = null; (e = bufferedReader.readLine()) != null; result = result + e + "\r\n") {
               ;
            }
         } catch (Exception var9) {
            var9.printStackTrace();
         }
      } catch (Exception var10) {
         var10.printStackTrace();
      } finally {
         if(bufferedReader != null) {
            bufferedReader.close();
         }

         if(fileReader != null) {
            fileReader.close();
         }

      }

      logger.debug("读取出来的文件内容是：\r\n" + result);
      return result;
   }

   public static boolean writeContentToFile(String content, String fileName, String encoding) throws Exception {
      Object mm = null;
      boolean flag = false;
      FileOutputStream o = null;
      File f = new File(fileName);

      try {
         o = new FileOutputStream(f);
         o.write(content.getBytes(encoding));
         o.close();
         flag = true;
      } catch (Exception var11) {
         var11.printStackTrace();
      } finally {
         if(o != null) {
            o.close();
         }

         if(mm != null) {
            ((RandomAccessFile)mm).close();
         }

      }

      return flag;
   }

   public static void contentToTxt(String filePath, String content, boolean isAppend) {
      new String();
      String s1 = new String();

      try {
         File e = new File(filePath);
         if(e.exists()) {
            logger.debug("文件存在");
            if(!isAppend) {
               e.delete();
               e.createNewFile();
            }
         } else {
            logger.debug("文件不存在");
            e.createNewFile();
         }

         String str;
         BufferedReader input;
         for(input = new BufferedReader(new FileReader(e)); (str = input.readLine()) != null; s1 = s1 + str + System.getProperty("line.separator")) {
            ;
         }

         System.out.println(s1);
         input.close();
         s1 = s1 + content;
         BufferedWriter output = new BufferedWriter(new FileWriter(e));
         output.write(s1);
         output.close();
      } catch (Exception var8) {
         var8.printStackTrace();
      }

   }

   public static void deleteFile(String fileName) {
      if(!StringUtils.isEmpty(fileName)) {
         File file = new File(fileName);
         logger.info("删除文件" + file.getName());
         delete(file);
      }
   }

   private static void delete(File file) {
      if(file.exists()) {
         if(file.isDirectory()) {
            File[] listFiles = file.listFiles();
            if(listFiles != null) {
               File[] var5 = listFiles;
               int var4 = listFiles.length;

               for(int var3 = 0; var3 < var4; ++var3) {
                  File f = var5[var3];
                  delete(f);
               }
            }

            file.delete();
         } else {
            file.delete();
         }

      }
   }

   public static void unZip(String srcFile, String destDirPath) {
      long start = System.currentTimeMillis();
      ZipFile zipFile = null;

      try {
         zipFile = new ZipFile(srcFile);
         Enumeration e = zipFile.entries();

         while(e.hasMoreElements()) {
            ZipEntry end = (ZipEntry)e.nextElement();
            logger.info("解压" + end.getName());
            if(end.isDirectory()) {
               String targetFile1 = destDirPath + "/" + end.getName();
               File is1 = new File(targetFile1);
               is1.mkdirs();
            } else {
               File targetFile = new File(destDirPath + "/" + end.getName());
               if(!targetFile.getParentFile().exists()) {
                  targetFile.getParentFile().mkdirs();
               }

               targetFile.createNewFile();
               InputStream is = zipFile.getInputStream(end);
               FileOutputStream fos = new FileOutputStream(targetFile);
               byte[] buf = new byte[2048];

               int len;
               while((len = is.read(buf)) != -1) {
                  fos.write(buf, 0, len);
               }

               fos.close();
               is.close();
            }
         }

         long end1 = System.currentTimeMillis();
         logger.info("解压完成，耗时：" + (end1 - start) + " ms");
      } catch (Exception var19) {
         throw new RuntimeException("unzip error from ZipUtils", var19);
      } finally {
         if(zipFile != null) {
            try {
               zipFile.close();
            } catch (IOException var18) {
               var18.printStackTrace();
            }
         }

      }
   }

   public static Long getRecodeNum(String fileName, String encoding) {
      Long recodeNum = Long.valueOf(0L);
      Stream stream = null;

      try {
         File e = new File(fileName);
         stream = Files.lines(Paths.get(e.getPath(), new String[0]), Charset.forName(encoding));
         recodeNum = Long.valueOf(stream.count());
      } catch (IOException var8) {
         var8.printStackTrace();
      } finally {
         if(stream != null) {
            stream.close();
         }

      }

      return recodeNum;
   }

   public static void main(String[] args) throws Exception {
      String num = "100001--2";
      String num1 = num.substring(0, num.indexOf("--"));
      System.out.println(num1);
      String num2 = num.substring(num1.length() + 1, num.length());
      System.out.println(num2);
      System.out.println(Integer.valueOf(num2).intValue() + 1);
      String fileName = "E:\\华软\\空中充值\\黑龙江\\自营记账卡\\清分与银行http接口示例及说明\\测试文件\\日常消费流水\\910_20160422_1461311370255_TB_EExit.txt";
      System.out.println(getRecodeNum(fileName, "GBK"));
   }
}
